# gmuse Development Guidelines

Auto-generated from all feature plans. Last updated: 2025-11-28

## Active Technologies

- Python 3.10+ (existing project requirement) (001-llm-commit-messages)

## Project Structure

```text
src/
tests/
```

## Commands

cd src [ONLY COMMANDS FOR ACTIVE TECHNOLOGIES][ONLY COMMANDS FOR ACTIVE TECHNOLOGIES] pytest [ONLY COMMANDS FOR ACTIVE TECHNOLOGIES][ONLY COMMANDS FOR ACTIVE TECHNOLOGIES] ruff check .

## Code Style

Code style MUST follow the `gmuse` Constitution: type hints, docstrings, Ruff-compatible formatting, and mypy type checks. Include links to the specific `pyproject.toml` sections and nox targets to run checks locally.

## Recent Changes

- 001-llm-commit-messages: Added Python 3.10+ (existing project requirement)

<!-- MANUAL ADDITIONS START -->
<!-- MANUAL ADDITIONS END -->
